;; Generated package description from zuul.el  -*- no-byte-compile: t -*-
(define-package "zuul" "0.4.0.0.20220905.135550" "Interface to Zuul" '((emacs "27.1") (project "0.8.1")) :commit "4afc08535f7d091c80978b2683d5813ca1970971" :authors '(("Niklas Eklund" . "niklas.eklund@posteo.net")) :maintainer '("zuul.el Development" . "~niklaseklund/zuul.el@lists.sr.ht") :keywords '("convenience" "tools") :url "https://sr.ht/~niklaseklund/zuul.el")
